==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ThisWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OffsettableWeekExpressionDescriptionMetadata } from "./OffsettableWeekExpressionDescriptionMetadata";
import { ThisWeekExpressionDescription } from "./ThisWeekExpressionDescription";
/**
 * @hidden
 */
var ThisWeekExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ThisWeekExpressionDescriptionMetadata, _super);
    function ThisWeekExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ThisWeekExpressionDescriptionMetadata.b = function (a) {
        if (ThisWeekExpressionDescriptionMetadata.a == null) {
            ThisWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ThisWeekExpressionDescriptionMetadata.c(ThisWeekExpressionDescriptionMetadata.a);
        }
        if (a.j(ThisWeekExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(ThisWeekExpressionDescriptionMetadata.a);
    };
    ThisWeekExpressionDescriptionMetadata.c = function (a) {
        OffsettableWeekExpressionDescriptionMetadata.c(a);
    };
    ThisWeekExpressionDescriptionMetadata.d = function (a) {
        ThisWeekExpressionDescriptionMetadata.b(a);
        a.aa("ThisWeekExpression", function () { return new ThisWeekExpressionDescription(); });
        a.z("ThisWeekExpression", ThisWeekExpressionDescriptionMetadata.a);
    };
    ThisWeekExpressionDescriptionMetadata.$t = markType(ThisWeekExpressionDescriptionMetadata, 'ThisWeekExpressionDescriptionMetadata');
    ThisWeekExpressionDescriptionMetadata.a = null;
    return ThisWeekExpressionDescriptionMetadata;
}(Base));
export { ThisWeekExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/ThisWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OffsettableWeekExpressionDescriptionMetadata } from "./OffsettableWeekExpressionDescriptionMetadata";
import { ThisWeekExpressionDescription } from "./ThisWeekExpressionDescription";
/**
 * @hidden
 */
var ThisWeekExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ThisWeekExpressionDescriptionMetadata, _super);
    function ThisWeekExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ThisWeekExpressionDescriptionMetadata.b = function (a) {
        if (ThisWeekExpressionDescriptionMetadata.a == null) {
            ThisWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ThisWeekExpressionDescriptionMetadata.c(ThisWeekExpressionDescriptionMetadata.a);
        }
        if (a.k(ThisWeekExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(ThisWeekExpressionDescriptionMetadata.a);
    };
    ThisWeekExpressionDescriptionMetadata.c = function (a) {
        OffsettableWeekExpressionDescriptionMetadata.c(a);
    };
    ThisWeekExpressionDescriptionMetadata.d = function (a) {
        ThisWeekExpressionDescriptionMetadata.b(a);
        a.ac("ThisWeekExpression", function () { return new ThisWeekExpressionDescription(); });
        a.ab("ThisWeekExpression", ThisWeekExpressionDescriptionMetadata.a);
    };
    ThisWeekExpressionDescriptionMetadata.$t = markType(ThisWeekExpressionDescriptionMetadata, 'ThisWeekExpressionDescriptionMetadata');
    ThisWeekExpressionDescriptionMetadata.a = null;
    return ThisWeekExpressionDescriptionMetadata;
}(Base));
export { ThisWeekExpressionDescriptionMetadata };
